@@ -70,6 +70,17 @@ BOX_TYPE_CONF: dict[str, dict[int, dict[str, Any]]] = {
     },
     # dimmerBox
     "dimmerBox": {
+        default_api_level: {
+            "api_path": "/api/dimmer/state",
+            "api": {
+                "set": lambda x: (
+                    "POST",
+                    "/api/dimmer/set",
+                    '{"dimmer":{"desiredBrightness": ' + str(x) + "}}",
+                ),
+            },
+            "lights": [["brightness", {"desired": "dimmer/desiredBrightness"}]],
+        },
         20170829: {
             "api_path": "/api/dimmer/state",
             "api": {
@@ -170,12 +181,11 @@ BOX_TYPE_CONF: dict[str, dict[int, dict[str, Any]]] = {
                         "state": "thermo/state",
                         "mode": "thermo/mode",
                         "safetySensorId": "thermo/safetyTempSensor/sensorId",
-                        "operatingState": "thermo/operatingState"
-                    }
+                        "operatingState": "thermo/operatingState",
+                    },
                 ]
-            ]
+            ],
         }
-
     },
     "saunaBox": {
         20180604: {
@@ -211,6 +221,7 @@ BOX_TYPE_CONF: dict[str, dict[int, dict[str, Any]]] = {
                 "close": lambda x=None: ("GET", "/s/d", None),
                 "position": lambda x: ("GET", "/s/p/" + str(x), None),
                 "stop": lambda x=None: ("GET", "/s/s", None),
+                "tilt": lambda x=None: ("GET", "/s/t/" + str(x), None),
             },
             "covers": [
                 [
@@ -218,6 +229,7 @@ BOX_TYPE_CONF: dict[str, dict[int, dict[str, Any]]] = {
                     {
                         "desired": "shutter/desiredPos/position",
                         # "current": "shutter/currentPos/position",
+                        "tilt": "shutter/desiredPos/tilt",
                         "state": "shutter/state",
                     },
                     "shutter",
@@ -249,7 +261,7 @@ BOX_TYPE_CONF: dict[str, dict[int, dict[str, Any]]] = {
             "switches": [["0.relay", {"state": "[relay=0]/state"}, "relay"]],
         },
         20190808: {
-            "api_path": "/api/relay/state",
+            "api_path": "/api/relay/extended/state",
             "extended_state_path": "/api/relay/extended/state",
             "api": {
                 "on": lambda x=None: ("GET", "/s/1", None),
@@ -258,6 +270,10 @@ BOX_TYPE_CONF: dict[str, dict[int, dict[str, Any]]] = {
             "switches": [
                 ["0.relay", {"state": lambda x: f"relays/[relay={x}]/state"}, "relay"]
             ],
+            "sensors": [
+                ["switchBox.energy", {"energy": "powerMeasuring/powerConsumption/[0]/value",
+                              "measurment_enabled": "powerMeasuring/enabled"}]
+            ]
         },
     },
     # switchBoxD
@@ -281,8 +297,7 @@ BOX_TYPE_CONF: dict[str, dict[int, dict[str, Any]]] = {
                     {"state": lambda x: f"relays/[relay={x}]/state"},
                     "relay",
                     1,
-                ]
-
+                ],
             ],
         }
     },
@@ -305,6 +320,27 @@ BOX_TYPE_CONF: dict[str, dict[int, dict[str, Any]]] = {
     },
     # wLightBox
     "wLightBox": {
+        default_api_level: {
+            "api_path": "/api/device/state",
+            "api": {
+                "set": lambda x: (
+                    "POST",
+                    "/api/rgbw/set",
+                    f'{{"rgbw":{{"desiredColor": "{str(x)}"}}}}',
+                ),
+            },
+            "lights": [
+                [
+                    "color",
+                    {
+                        "desired": "rgbw/desiredColor",
+                        "last_color": "rgbw/lastOnColor",
+                        "currentEffect": "rgbw/effectID",
+                        "colorMode": "rgbw/colorMode",
+                    },
+                ]
+            ],
+        },
         20190808: {
             "api_path": "/api/rgbw/state",
             "extended_state_path": "/api/rgbw/extended/state",
@@ -354,6 +390,24 @@ BOX_TYPE_CONF: dict[str, dict[int, dict[str, Any]]] = {
     },
     # wLightBoxS
     "wLightBoxS": {
+        default_api_level:{
+            "api_path": "/api/device/state",
+            "api": {
+                "set": lambda x: (
+                    "POST",
+                    "/api/light/set",
+                    f'{{"light": {{"desiredColor": "{x}"}}}}',
+                ),
+            },
+            "lights": [
+                [
+                    "brightness",
+                    {
+                        "desired": "light/desiredColor",
+                    },
+                ]
+            ],
+        },
         20180718: {
             "api_path": "/api/light/state",
             "api": {
@@ -407,6 +461,7 @@ BOX_TYPE_CONF: dict[str, dict[int, dict[str, Any]]] = {
                     {
                         "temperature": lambda x: f"multiSensor/sensors/[id={x}]/value",
                         "wind": lambda x: f"multiSensor/sensors/[id={x}]/value",
+                        "humidity": lambda x: f"multiSensor/sensors/[id={x}]/value",
                     },
                 ]
             ],
